==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QVariantAnimation_shell.h <==
#ifndef QVARIANTANIMATION_SHELL_H
#define QVARIANTANIMATION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(animation)
#include <QtCore/qvariantanimation.h>
#endif //QT_CONFIG(animation)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#if QT_CONFIG(animation)
#include <QtCore/qabstractanimation.h>
#endif //QT_CONFIG(animation)
#if QT_CONFIG(animation)
#include <QtCore/qanimationgroup.h>
#endif //QT_CONFIG(animation)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(easingcurve)
#include <QtCore/qeasingcurve.h>
#endif //QT_CONFIG(easingcurve)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(animation)

class QVariantAnimation_shell : public QVariantAnimation, public QtJambiShellInterface
{
public:
    QVariantAnimation_shell(QObject* parent0 = nullptr);
    ~QVariantAnimation_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    int duration() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant interpolated(const QVariant& from0, const QVariant& to1, qreal progress2) const override;
    void timerEvent(QTimerEvent* event0) override;
    void updateCurrentTime(int arg__1) override;
    void updateCurrentValue(const QVariant& value0) override;
    void updateDirection(QAbstractAnimation::Direction direction0) override;
    void updateState(QAbstractAnimation::State newState0, QAbstractAnimation::State oldState1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVariantAnimation_access : public QVariantAnimation
{
    jint __qt_duration(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_interpolated_cref_QVariant_cref_QVariant_qreal_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject from0, jobject to1, jdouble progress2) const;
    void __qt_updateCurrentTime_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    void __qt_updateCurrentValue_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject value0);
    void __qt_updateState_QAbstractAnimation_State_QAbstractAnimation_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0, jint oldState1);
};

#endif // QT_CONFIG(animation)
#endif // QVARIANTANIMATION_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QVariantAnimation_shell.h <==
#ifndef QVARIANTANIMATION_SHELL_H
#define QVARIANTANIMATION_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtcore-config.h>
#if QT_CONFIG(animation)
#include <QtCore/qvariantanimation.h>
#endif //QT_CONFIG(animation)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#if QT_CONFIG(animation)
#include <QtCore/qabstractanimation.h>
#endif //QT_CONFIG(animation)
#if QT_CONFIG(animation)
#include <QtCore/qanimationgroup.h>
#endif //QT_CONFIG(animation)
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qcoreevent.h>
#if QT_CONFIG(easingcurve)
#include <QtCore/qeasingcurve.h>
#endif //QT_CONFIG(easingcurve)
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(animation)

class QVariantAnimation_shell : public QVariantAnimation, public QtJambiShellInterface
{
public:
    QVariantAnimation_shell(QObject* parent0 = nullptr);
    ~QVariantAnimation_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    int duration() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QVariant interpolated(const QVariant& from0, const QVariant& to1, qreal progress2) const override;
    void timerEvent(QTimerEvent* event0) override;
    void updateCurrentTime(int arg__1) override;
    void updateCurrentValue(const QVariant& value0) override;
    void updateDirection(QAbstractAnimation::Direction direction0) override;
    void updateState(QAbstractAnimation::State newState0, QAbstractAnimation::State oldState1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVariantAnimation_access : public QVariantAnimation
{
    jint __qt_duration_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0);
    jobject __qt_interpolated_cref_QVariant_cref_QVariant_qreal_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject from0, jobject to1, jdouble progress2) const;
    void __qt_updateCurrentTime_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint arg__1);
    void __qt_updateCurrentValue_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject value0);
    void __qt_updateState_QAbstractAnimation_State_QAbstractAnimation_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint newState0, jint oldState1);
};

#endif // QT_CONFIG(animation)
#endif // QVARIANTANIMATION_SHELL_H
